{ config, lib, pkgs, ... }: {

  home.sessionVariables.STARSHIP_CACHE = "${config.xdg.cacheHome}/starship";
  home.packages = with pkgs; [ starship ];
  programs.starship = {
    enable = true;
    enableFishIntegration = false;
    enableIonIntegration = false;
    enableNushellIntegration = false;
    enableZshIntegration = true;
    settings = {
      format = lib.concatStrings [
        "[░▒▓](#${config.colorScheme.palette.base06})"
        "$username"
        "$hostname"
        "[](bg:#${config.colorScheme.palette.base05} fg:#${config.colorScheme.palette.base06})"
        "$directory"
        "[](bg:#${config.colorScheme.palette.base04} fg:#${config.colorScheme.palette.base05})"
        "[ ](bg:#${config.colorScheme.palette.base04})"
        "$env_var"
        "[](bg:#${config.colorScheme.palette.base00} fg:#${config.colorScheme.palette.base04})"
        " "
      ];
      username = {
        show_always = true;
        style_user =
          "bg:#${config.colorScheme.palette.base06} fg:#${config.colorScheme.palette.base00}";
        style_root =
          "bg:#${config.colorScheme.palette.base06} fg:#${config.colorScheme.palette.base00}";
        format = "[ $user]($style)";
      };
      hostname = {
        ssh_symbol = "";
        style =
          "bg:#${config.colorScheme.palette.base06} fg:#${config.colorScheme.palette.base00}";
        format = "[@$hostname]($style)";
        ssh_only = false;
        disabled = false;
      };
      directory = {
        style =
          "bg:#${config.colorScheme.palette.base05} fg:#${config.colorScheme.palette.base00}";
        format = "[ $path ]($style)";
        truncation_length = 3;
        truncation_symbol = "…/";
      };
      directory.substitutions = {
        "documents" = "󰮜 ";
        "downloads" = "󱃩 ";
        "files" = "󱧷 ";
        "media" = "󱍚 ";
      };
      env_var = {
        variable = "SHELLENVTYPE";
        default = "";
        style =
          "bg:#${config.colorScheme.palette.base04} fg:#${config.colorScheme.palette.base00}";
        format = "[$env_value]($style)";
      };
    };
  };
}
